// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated by protoc-gen-go. DO NOT EDIT.
// source: cmd/protoc-gen-go/testdata/imports/test_import_a1m2.proto

package imports

import (
	test_a_1 "google.golang.org/protobuf/cmd/protoc-gen-go/testdata/imports/test_a_1"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

type A1M2 struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	F             *test_a_1.M2           `protobuf:"bytes,1,opt,name=f,proto3" json:"f,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *A1M2) Reset() {
	*x = A1M2{}
	mi := &file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *A1M2) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*A1M2) ProtoMessage() {}

func (x *A1M2) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use A1M2.ProtoReflect.Descriptor instead.
func (*A1M2) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDescGZIP(), []int{0}
}

func (x *A1M2) GetF() *test_a_1.M2 {
	if x != nil {
		return x.F
	}
	return nil
}

var File_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto protoreflect.FileDescriptor

const file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDesc = "" +
	"\n" +
	"9cmd/protoc-gen-go/testdata/imports/test_import_a1m2.proto\x12\x04test\x1a4cmd/protoc-gen-go/testdata/imports/test_a_1/m2.proto\" \n" +
	"\x04A1M2\x12\x18\n" +
	"\x01f\x18\x01 \x01(\v2\n" +
	".test.a.M2R\x01fB?Z=google.golang.org/protobuf/cmd/protoc-gen-go/testdata/importsb\x06proto3"

var (
	file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDescOnce sync.Once
	file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDescData []byte
)

func file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDescGZIP() []byte {
	file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDescOnce.Do(func() {
		file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDesc)))
	})
	return file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDescData
}

var file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_goTypes = []any{
	(*A1M2)(nil),        // 0: test.A1M2
	(*test_a_1.M2)(nil), // 1: test.a.M2
}
var file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_depIdxs = []int32{
	1, // 0: test.A1M2.f:type_name -> test.a.M2
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_init() }
func file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_init() {
	if File_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_goTypes,
		DependencyIndexes: file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_depIdxs,
		MessageInfos:      file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_msgTypes,
	}.Build()
	File_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto = out.File
	file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_goTypes = nil
	file_cmd_protoc_gen_go_testdata_imports_test_import_a1m2_proto_depIdxs = nil
}
