// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

syntax = "proto2";

// File contains no 'package' statement.

enum Enum {
  ZERO = 0;
}

message Message {
  optional string string_field = 1;
  optional Enum enum_field = 2 [default = ZERO];
}
