// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated by protoc-gen-go. DO NOT EDIT.
// source: internal/testprotos/test/ext.proto

package test

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	unsafe "unsafe"
)

var file_internal_testprotos_test_ext_proto_extTypes = []protoimpl.ExtensionInfo{
	{
		ExtendedType:  (*TestAllExtensions)(nil),
		ExtensionType: (*int32)(nil),
		Field:         2000,
		Name:          "goproto.proto.test.foreign_int32_extension",
		Tag:           "varint,2000,opt,name=foreign_int32_extension",
		Filename:      "internal/testprotos/test/ext.proto",
	},
}

// Extension fields to TestAllExtensions.
var (
	// optional int32 foreign_int32_extension = 2000;
	E_ForeignInt32Extension = &file_internal_testprotos_test_ext_proto_extTypes[0]
)

var File_internal_testprotos_test_ext_proto protoreflect.FileDescriptor

const file_internal_testprotos_test_ext_proto_rawDesc = "" +
	"\n" +
	"\"internal/testprotos/test/ext.proto\x12\x12goproto.proto.test\x1a#internal/testprotos/test/test.proto:^\n" +
	"\x17foreign_int32_extension\x12%.goproto.proto.test.TestAllExtensions\x18\xd0\x0f \x01(\x05R\x15foreignInt32ExtensionB5Z3google.golang.org/protobuf/internal/testprotos/test"

var file_internal_testprotos_test_ext_proto_goTypes = []any{
	(*TestAllExtensions)(nil), // 0: goproto.proto.test.TestAllExtensions
}
var file_internal_testprotos_test_ext_proto_depIdxs = []int32{
	0, // 0: goproto.proto.test.foreign_int32_extension:extendee -> goproto.proto.test.TestAllExtensions
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	0, // [0:1] is the sub-list for extension extendee
	0, // [0:0] is the sub-list for field type_name
}

func init() { file_internal_testprotos_test_ext_proto_init() }
func file_internal_testprotos_test_ext_proto_init() {
	if File_internal_testprotos_test_ext_proto != nil {
		return
	}
	file_internal_testprotos_test_test_proto_init()
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_internal_testprotos_test_ext_proto_rawDesc), len(file_internal_testprotos_test_ext_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   0,
			NumExtensions: 1,
			NumServices:   0,
		},
		GoTypes:           file_internal_testprotos_test_ext_proto_goTypes,
		DependencyIndexes: file_internal_testprotos_test_ext_proto_depIdxs,
		ExtensionInfos:    file_internal_testprotos_test_ext_proto_extTypes,
	}.Build()
	File_internal_testprotos_test_ext_proto = out.File
	file_internal_testprotos_test_ext_proto_goTypes = nil
	file_internal_testprotos_test_ext_proto_depIdxs = nil
}
