// Copyright 2024 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

syntax = "proto2";

package lazy_extension_normalized_wire_test;

option go_package = "google.golang.org/protobuf/internal/testprotos/lazy";

message Sub {
  extensions 2 [verification = UNVERIFIED];
  optional uint32 c = 3;
  optional Sub grandchild = 4;
}

message Top {
  optional uint32 a = 1;
  optional Sub child = 2;
}

message Ext {
  extend Sub {
    optional Ext b = 2;
  }

  optional bool some_flag = 1;
}
