// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated by protoc-gen-go. DO NOT EDIT.
// source: cmd/protoc-gen-go/testdata/imports/test_a_1/m1.proto

package test_a_1

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

type E1 int32

const (
	E1_E1_ZERO E1 = 0
)

// Enum value maps for E1.
var (
	E1_name = map[int32]string{
		0: "E1_ZERO",
	}
	E1_value = map[string]int32{
		"E1_ZERO": 0,
	}
)

func (x E1) Enum() *E1 {
	p := new(E1)
	*p = x
	return p
}

func (x E1) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (E1) Descriptor() protoreflect.EnumDescriptor {
	return file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_enumTypes[0].Descriptor()
}

func (E1) Type() protoreflect.EnumType {
	return &file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_enumTypes[0]
}

func (x E1) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use E1.Descriptor instead.
func (E1) EnumDescriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescGZIP(), []int{0}
}

type M1 struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *M1) Reset() {
	*x = M1{}
	mi := &file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *M1) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*M1) ProtoMessage() {}

func (x *M1) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use M1.ProtoReflect.Descriptor instead.
func (*M1) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescGZIP(), []int{0}
}

type M1_1 struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	M1            *M1                    `protobuf:"bytes,1,opt,name=m1,proto3" json:"m1,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *M1_1) Reset() {
	*x = M1_1{}
	mi := &file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *M1_1) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*M1_1) ProtoMessage() {}

func (x *M1_1) ProtoReflect() protoreflect.Message {
	mi := &file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use M1_1.ProtoReflect.Descriptor instead.
func (*M1_1) Descriptor() ([]byte, []int) {
	return file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescGZIP(), []int{1}
}

func (x *M1_1) GetM1() *M1 {
	if x != nil {
		return x.M1
	}
	return nil
}

var File_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto protoreflect.FileDescriptor

const file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDesc = "" +
	"\n" +
	"4cmd/protoc-gen-go/testdata/imports/test_a_1/m1.proto\x12\x06test.a\"\x04\n" +
	"\x02M1\"\"\n" +
	"\x04M1_1\x12\x1a\n" +
	"\x02m1\x18\x01 \x01(\v2\n" +
	".test.a.M1R\x02m1*\x11\n" +
	"\x02E1\x12\v\n" +
	"\aE1_ZERO\x10\x00BHZFgoogle.golang.org/protobuf/cmd/protoc-gen-go/testdata/imports/test_a_1b\x06proto3"

var (
	file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescOnce sync.Once
	file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescData []byte
)

func file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescGZIP() []byte {
	file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescOnce.Do(func() {
		file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDesc)))
	})
	return file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDescData
}

var file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_goTypes = []any{
	(E1)(0),      // 0: test.a.E1
	(*M1)(nil),   // 1: test.a.M1
	(*M1_1)(nil), // 2: test.a.M1_1
}
var file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_depIdxs = []int32{
	1, // 0: test.a.M1_1.m1:type_name -> test.a.M1
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_init() }
func file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_init() {
	if File_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDesc), len(file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_rawDesc)),
			NumEnums:      1,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_goTypes,
		DependencyIndexes: file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_depIdxs,
		EnumInfos:         file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_enumTypes,
		MessageInfos:      file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_msgTypes,
	}.Build()
	File_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto = out.File
	file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_goTypes = nil
	file_cmd_protoc_gen_go_testdata_imports_test_a_1_m1_proto_depIdxs = nil
}
